// java wrapper for vtkOpenGLHardwareSelector object
//

package vtk;
import vtk.*;

public class vtkOpenGLHardwareSelector extends vtkHardwareSelector
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void BeginRenderProp_2();
  public void BeginRenderProp()
    { BeginRenderProp_2(); }

  private native void EndRenderProp_3();
  public void EndRenderProp()
    { EndRenderProp_3(); }

  private native void RenderCompositeIndex_4(int id0);
  public void RenderCompositeIndex(int id0)
    { RenderCompositeIndex_4(id0); }

  private native void RenderProcessId_5(int id0);
  public void RenderProcessId(int id0)
    { RenderProcessId_5(id0); }

  private native void BeginSelection_6();
  public void BeginSelection()
    { BeginSelection_6(); }

  private native void EndSelection_7();
  public void EndSelection()
    { EndSelection_7(); }

  public vtkOpenGLHardwareSelector() { super(); }

  public vtkOpenGLHardwareSelector(long id) { super(id); }
  public native long   VTKInit();

}
